# Moyopy

[![image](https://img.shields.io/pypi/v/moyopy.svg)](https://pypi.python.org/pypi/moyopy)
[![image](https://img.shields.io/pypi/l/moyopy.svg)](https://pypi.python.org/pypi/moyopy)
[![image](https://img.shields.io/pypi/pyversions/moyopy.svg)](https://pypi.python.org/pypi/moyopy)

Python interface of Moyo

## Installation

```shell
pip install moyopy
# If you want to convert structures into Pymatgen or ASE objects
pip install moyopy[interface]
```

## Examples

See [example directory](examples)
